--
-- moveCamera
-- Engine management specialization for a working position for the indoor camera
--
-- @author  Templaer
-- @date  3/07/09
--
-- Modifikationen erst nach Rcksprache
-- Do not edit without my permission
--

moveCamera = {};

function moveCamera.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function moveCamera:load(xmlFile)
	local translationCamera = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, "vehicle.translationCamera#index"));
    if translationCamera ~= nil then
        self.translationCamera = {};
        self.translationCamera.node = translationCamera;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationCamera#minTrans"));
        self.translationCamera.minTrans = {};
        self.translationCamera.minTrans[1] = Utils.getNoNil(x, 0);
        self.translationCamera.minTrans[2] = Utils.getNoNil(y, 0);
        self.translationCamera.minTrans[3] = Utils.getNoNil(z, 0);

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.translationCamera#maxTrans"));
        self.translationCamera.maxTrans = {};
        self.translationCamera.maxTrans[1] = Utils.getNoNil(x, 0);
        self.translationCamera.maxTrans[2] = Utils.getNoNil(y, 0);
        self.translationCamera.maxTrans[3] = Utils.getNoNil(z, 0);

        self.translationCamera.transTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.translationCamera#transTime"), 2)*1000;
    end; 	
end;

function moveCamera:delete()
end;

function moveCamera:mouseEvent(posX, posY, isDown, isUp, button)
end;

function moveCamera:keyEvent(unicode, sym, modifier, isDown)
    if self.isEntered and self.translationCamera ~= nil then
		if self.translationCamera.node ~= nil then
			if sym == Input.KEY_KP_4 then
				self.translationCameraLeft = isDown;
			end;
			
			if sym == Input.KEY_shift and isDown then
				self.cameras[self.camIndex]:resetCamera();
				local x, y, z = getRotation(self.translationCamera.node); 
				if y > 0 then
					y = 0;
				else
					y = 3.14159;
				end;
				local newRot = {x, y, z};
				setRotation(self.translationCamera.node, unpack(newRot));
			end;
			
			if sym == Input.KEY_KP_5 then
				local x, y, z = getTranslation(self.translationCamera.node); 
				if z ~= self.translationCamera.minTrans[3] then
					z = self.translationCamera.minTrans[3];
					local newTrans = {x, y, z};
					setTranslation(self.translationCamera.node, unpack(newTrans));
				end;
			end;
			
			if sym == Input.KEY_KP_6 then
				self.translationCameraRight = isDown;
			end;
		end;
	end;
end;

function moveCamera:update(dt)	
    if self.isEntered and self.translationCamera ~= nil then
		-- Handle the translation
		local doTranslate = self.translationCameraLeft or self.translationCameraRight
		if self.translationCamera ~= nil and doTranslate then 
			local x, y, z = getTranslation(self.translationCamera.node); 
			local trans = {x,y,z}; 
			local newTrans = Utils.getMovedLimitedValues(trans, self.translationCamera.maxTrans, self.translationCamera.minTrans, 3, self.translationCamera.transTime, dt, not self.translationCameraLeft); 
			setTranslation(self.translationCamera.node, unpack(newTrans)); 
		end;	
	end;
end;

function moveCamera:stopMotor()
end;
	
function moveCamera:onLeave()
end;

function moveCamera:draw()  
end;
